from time import sleep
from machine import Pin, PWM
import network
import uasyncio as asyncio
from microdot_asyncio import Microdot,Request,Response
#
led_pin = 20
button_pin = Pin(21, Pin.IN)
led = Pin(led_pin,Pin.OUT)
button = Pin(button_pin,Pin.IN,Pin.PULL_UP)
button_up = True

pwm = PWM(Pin(20))
pwm.freq(50)
#
# start Wifi access point
#
wifi = network.WLAN(network.AP_IF)
wifi.config(ssid='fab',key='class')
wifi.active(True) # 192.168.4.1
while (wifi.active() == False):
  pass
print("AP started at",wifi.ifconfig())
print("ssid: fab, key: class")
#
# connect to Wifi access point
#
'''
wifi = network.WLAN(network.STA_IF)
wifi.active(True)
while (wifi.active() == False):
   pass
wifi.connect("ssid","key")
while (wifi.isconnected() == False):
   pass
print("connected to AP at ",wifi.ifconfig())
'''
#
# create Web server
#
server = Microdot()
#
# root Web page
#
def root_page():
    html = '''
<!DOCTYPE html>
<html lang="en">
<head>
<script>
function TurnOn() {
   fetch('on')
    .then(response => response.text())
    .then(data => {
         document.getElementById('message').innerHTML = data
         })
   }
function TurnOff() {
   fetch('off')
    .then(response => response.text())
    .then(data => {
         document.getElementById('message').innerHTML = data
         })
   }
</script>
</head>
<body>
<button onclick='TurnOn()'>turn motor on</button>&nbsp;
<button onclick='TurnOff()'>turn motor off</button>&nbsp;
<div id='message'></div>
</body>
</html>
    '''
    return html
#
# server routes
#
@server.get('/')
async def get_root(request):
    return root_page(),200,{'Content-Type':'text/html'}
@server.get('/on')
async def get_on(request):
    for position in range(1000, 9000, 50):
        pwm.duty_u16(position)
        sleep(0.01)
    for position in range(9000, 1000, -50):
        pwm.duty_u16(position)
        sleep(0.01)
    return "motor is on",200,{'Content-Type':'text/html'}
@server.get('/off')
async def get_off(request):
    pwm.duty_u16(0)
    sleep(0.1)
    return "motor is off",200,{'Content-Type':'text/html'}
#
# local task
#
async def local():
    global button_up
    while True:
        if button_pin.value() == 0:  # Assuming the button pulls the pin to ground when pressed
            for position in range(1000, 9000, 50):
                pwm.duty_u16(position)
                sleep(0.01)
            for position in range(9000, 1000, -50):
                pwm.duty_u16(position)
                sleep(0.01)
                print('motor on')
                button_up = False
        elif ((button.value() == 1) and (not button_up)):
            pwm.duty_u16(0)
            sleep(0.1)
            print('motor off')
            button_up = True
        await asyncio.sleep(0)
#
# main tasks
#
async def main():
    local_task = asyncio.create_task(local())
    server_task = asyncio.create_task(server.start_server(port=80,debug=True))
    await asyncio.gather(local_task,server_task)
#
# run main tasks
#
asyncio.run(main())
